#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

option add *background #b8b8f8
option add *activeBackground #d8d8ff
option add *borderwidth 2
option add *foreground black

global env exec_dir pwd home toolflag storedir install_dir tclsrc_dir
global fracversion

##############################################
set fracversion 1.2.2
###############################################
set compile 0
set DOS 0
set home $env(HOME)
set install_dir [file dir [info script]]
set mftrcs $home/.local/MFT

set arch [lindex $tcl_platform(os) 0]
if {[string match Windows* $arch]==1} {
	set DOS 1
    set install_dir .
	set mftrcs $home
}
if {[string match Darwin* $arch]==1} {
	set DOS 2
    set install_dir [file dir [info script]]
	set mftrcs $home/Library/Application\ Support/MFT
# auf MacOS Mojave prüfen	
	if {[string match 18* [lindex $tcl_platform(osVersion) 0]]} {set DOS 3}
}

##########################################################################
# Preparing fileboxes (not necessary but nice for hidden files)
if {$DOS==0} {
   catch { tk_getOpenFile -w00t } ;# start file dialog with unknown option
       set ::tk::dialog::file::showHiddenBtn 1 
       set ::tk::dialog::file::showHiddenVar 0
} 
##########################################################################

set tclsrc_dir $install_dir/tclsrc
set exec_dir $install_dir/bin
set storedir $mftrcs/mftfiles
set default_storedir $storedir

if ![file exist $mftrcs] {file mkdir $mftrcs}
if ![file exist $storedir] {file copy $install_dir/mftfiles $storedir}


set dirlist "general fractals mandel ifs bifu slope plotter automat"

 foreach item $dirlist {
  if {$compile==1} {auto_mkindex $tclsrc_dir/$item *.tcl}
  lappend autopath $tclsrc_dir/$item
  set dir $tclsrc_dir/$item
  set unit [open $tclsrc_dir/$item/tclIndex]
  eval [read $unit]
  close $unit
}

readdefaults


 # Global definitions
#-------------------
global colorlist color blue yellow green violet dblue
set colorlist {black red limegreen blue3 gold cyan purple magenta green}
set blue #B8B8F8

set red #DD0000
set yellow #EEEE00
set green #00AA00
set violet #AA00AA
set dblue #0000FF

set color(0) #B8B8F8
set color(1) #DD0000
set color(2) #00AA00
set color(3) #EEEE00
set color(4) #0000FF
set color(5) #AA00AA
set color(6) #eb8000
set color(7) #e623ff
set color(8) #bd4b00
set color(9) #8f7700
set color(10) #659f00
set color(11) #37cb00
set color(12) #0df300
set color(13) #00df26
set color(14) #00b74d
set color(15) #008a77
set color(16) #00629e
set color(17) #0035c8
set color(18) #000def
set color(19) #0000e3
set color(20) #0000bb
set color(21) #00008e
set color(22) #000066
set color(23) #000039
set color(24) #000011


global taglist
set taglist [concat axis $colorlist]
global plotFontN plotFontS plotFontT
global boldFontN boldFontS boldFontT

# set plotFontN -*-Helvetica-Medium-R-Normal--*-120-*-*-*-*-*-*
# set plotFontS -*-Helvetica-Medium-R-Normal--*-100-*-*-*-*-*-*
# set plotFontT -*-Helvetica-Medium-R-Normal--*-80-*-*-*-*-*-*
# 
# set boldFontN -*-Helvetica-Bold-R-Normal--*-120-*-*-*-*-*-*
# set boldFontS -*-Helvetica-Bold-R-Normal--*-120-*-*-*-*-*-*
# set boldFontT -*-Helvetica-Bold-R-Normal--*-80-*-*-*-*-*-*

global textFont
# set textFont -*-Courier-Bold-R-Normal--*-120-*-*-*-*-*-*

global infoFont
# set infoFont -*-Helvetica-Bold-R-Normal--*-120-*-*-*-*-*-*

# Listbox height in Zeilen
global lbheight 
set lbheight 10

global can smallscreen
set can 600
set smallscreen 0

global plotcounter
set plotcounter 0
set sizedetect 0

if {[winfo screenheight .] <=1600} {set sizedetect 4}
if {[winfo screenheight .] <=1024} {set sizedetect 3}
if {[winfo screenheight .] <=800} {set sizedetect 2}
if {[winfo screenheight .] <=600} {set sizedetect 1}
#set sizedetect 2
#if {[winfo screenheight .] <=2000} {set sizedetect 1}

switch $sizedetect {

1 {       set smallscreen 1
            set can 500
            set lbheight 5
            set ff 60
            set tt 40
}
2 {       set smallscreen 0
            set can 600
            set lbheight 5
             set ff 80
             set tt 60
}

3 {       set smallscreen 0
            set can 700
            set lbheight 10
            set ff 100
            set tt 80
}
4 {       set smallscreen 0
            set can 800
            set lbheight 15
            set ff 120
            set tt 100
}

default {  
            set smallscreen 0
            set can 800
            set lbheight 10
            set ff 100
            set tt 80
}


}
 set plotFontN -*-Helvetica-Medium-R-Normal--*-$ff-*-*-*-*-*-*
 set plotFontS -*-Helvetica-Medium-R-Normal--*-$ff-*-*-*-*-*-*
 set plotFontT -*-Helvetica-Medium-R-Normal--*-$tt-*-*-*-*-*-*
 set boldFontN -*-Helvetica-Bold-R-Normal--*-$ff-*-*-*-*-*-*
 set boldFontS -*-Helvetica-Bold-R-Normal--*-$ff-*-*-*-*-*-*
 set boldFontT -*-Helvetica-Bold-R-Normal--*-$tt-*-*-*-*-*-*
 set textFont -*-Courier-Bold-R-Normal--*-$ff-*-*-*-*-*-*
 set infoFont -*-Helvetica-Bold-R-Normal--*-$ff-*-*-*-*-*-*


#------------------------------
# Window manager configurations
#------------------------------

global tkVersion
wm positionfrom . user
wm sizefrom . ""
wm geometry . "+400+50"

wm title . "Tiger Graphics Mathtools $fracversion"

wm iconmask . @$install_dir/icons/tinylogo.pic
wm iconbitmap . @$install_dir/icons/tinylogo.pic

frame .top -borderwidth 10

pack .top -side top -fill x

frame .top.top -borderwidth 10
frame .top.bottom -borderwidth 10


button .top.top.fractals -bitmap @$install_dir/icons/fractals.xbm -fg Black -command {set toolflag fractals;tools;disablemenu}
button .top.top.julia -bitmap @$install_dir/icons/julia.xbm -command {set toolflag mandel;tools;disablemenu}
button .top.top.richt -bitmap @$install_dir/icons/slope.xbm -command {set toolflag slope;tools;disablemenu}
button .top.top.automat -bitmap @$install_dir/icons/automat.xbm -command {set toolflag automat;tools;disablemenu}
button .top.top.custom -bitmap @$install_dir/icons/custom.xbm -command {customtool;disablemenu}


button .top.bottom.ifs -bitmap @$install_dir/icons/ifs.xbm -command {set toolflag ifs;tools;disablemenu}
button .top.bottom.bifu -bitmap @$install_dir/icons/bifu.xbm -command {set toolflag bifu;tools;disablemenu}
button .top.bottom.plot -bitmap @$install_dir/icons/plotter.xbm -command {set toolflag plot;tools;disablemenu}
button .top.bottom.help -bitmap @$install_dir/icons/help.xbm -command {help main}
button .top.bottom.tatze -bitmap @$install_dir/icons/tatze.xbm -command {tatzetool}

pack  .top.top.fractals -side left -fill x
pack  .top.top.julia -side left -fill x
pack  .top.top.richt -side left -fill x
pack  .top.top.automat -side left -fill x
pack  .top.top.custom -side left -fill x

pack  .top.bottom.ifs -side left -fill x
pack  .top.bottom.bifu -side left -fill x
pack  .top.bottom.plot -side left -fill x
pack  .top.bottom.help -side left -fill x
pack  .top.bottom.tatze -side left


pack .top.top -fill x
pack .top.bottom -fill x


button  .top.exit -text {Bye Bye} -command {destroy .} -font $boldFontN
pack  .top.exit -fill x -side bottom

# Für Windows
if {$DOS==1} {console hide}


