/* TigerGraphics Math and Fractal Tool 1.2 Copyright (C) 2004, Cora Kohlmeier, Frank Hamberg */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "constructs.h"
#include <signal.h>
#include <sys/types.h>
#include <unistd.h>

int main(int argc, char *argv[]);

int main(int argc, char *argv[])
{
int kill(pid_t pid, int sig);
FILE *pict,*colt;
int max_col;
double d;
char filename[256];
char colors[256],test;
char r[255],g[255],b[255];

int argcount=1,i,j,k,l,m,t,n,nmax,newworld,mypid;
double Da,Db,ma,mb,epsa,epsb,qa;
double **A,**saveA,**B,**saveB;
double acti,inhi,delta=0.01;

int eusteps, outcount;
mypid=getpid();

sscanf(argv[argcount++],"%d",&nmax);
sscanf(argv[argcount++],"%d",&newworld);
sscanf(argv[argcount++],"%lf",&Db);
sscanf(argv[argcount++],"%lf",&ma);
sscanf(argv[argcount++],"%lf",&mb);
sscanf(argv[argcount++],"%lf",&epsa);
sscanf(argv[argcount++],"%lf",&epsb);
sscanf(argv[argcount++],"%lf",&qa);
sprintf(colors,"%s",argv[argcount++]);
sprintf(filename,"%s",argv[argcount++]);

/* Farbtabelle einlesen */
colt=fopen(colors,"r");
l=0;
while ((test=fgetc(colt))!=EOF && l<255)
 {
 ungetc(test,colt);
 fscanf(colt,"%d",&r[l]);
 fscanf(colt,"%d",&g[l]);
 fscanf(colt,"%d",&b[l]);
 l++;
 }
max_col=l-1;
d=(double) (max_col/ 2.0);

Da=Db/qa;

A = dmatrix(-1,nmax+1,-1,nmax+1);/*Aktivator*/
saveA = dmatrix(-1,nmax+1,-1,nmax+1);
B = dmatrix(-1,nmax+1,-1,nmax+1);/*Inhibitor*/
saveB = dmatrix(-1,nmax+1,-1,nmax+1);/*Inhibitor*/

for (i=-1;i<=nmax+1;i++)
   for (j=-1;j<=nmax+1;j++)
   {
     saveA[i][j]=0.0;
     saveB[i][j]=0.0;
     A[i][j]=0.0;
     B[i][j]=0.0;
   }

/* Einlesen der Startwerte    */
/* Aktivator */
for (i=0;i<=nmax;i++)
   for (j=0;j<=nmax;j++)
   {
     sscanf(argv[argcount++],"%lf",&acti);
     if (acti < 0.0) acti=0.0;
     A[i][j]=saveA[i][j]=acti;
   }
/* Inhibitor */
for (i=0;i<=nmax;i++)
   for (j=0;j<=nmax;j++)
   {
     sscanf(argv[argcount++],"%lf",&inhi);
     if (inhi < 0.0) inhi=0.0;
     B[i][j]=saveB[i][j]=inhi;
   }

/* 10 Schritte, dann erst Ausgabe */
while (1) 
{
for (t=0;t<10;t++)
{
/* Reaction and Diffusion*/
for (i=0;i<=nmax;i++)
    for (j=0;j<=nmax;j++)
    {
    /* Bestimmung der Nachbarindizes */
      k= i-1;
      l= j-1;
      m= i+1;
      n= j+1;

      if (newworld==1) {
    /* Setzen der Randindizes */
         if (i==0) k=nmax;
         if (i==nmax) m=0;
         if (j==0) l=nmax;
         if (j==nmax) n=0;
      }


/* Reaction Activator */
saveA[i][j]=A[i][j];
A[i][j] +=(A[i][j]*A[i][j]/B[i][j] + epsa  -ma*A[i][j])*delta;

/* Reaction Inhibitor */
saveB[i][j]=B[i][j];
B[i][j] +=(saveA[i][j]*saveA[i][j] +epsb -mb*B[i][j])*delta;

/* Diffusion Activator */
      acti      = saveA[i][j];

      A[i][j] -= 4.0*Da*acti*delta;
      A[k][j] += Da*acti*delta;
      A[i][n] += Da*acti*delta;
      A[m][j] += Da*acti*delta;
      A[i][l] += Da*acti*delta;

/* Diffusion Inhibitor */
      inhi      = saveB[i][j];

      B[i][j] -= 4.0*Db*inhi*delta;
      B[k][j] += Db*inhi*delta;
      B[i][n] += Db*inhi*delta;
      B[m][j] += Db*inhi*delta;
      B[i][l] += Db*inhi*delta;


}

}


/* Ausgabe in ppm und für tcl*/
pict=fopen(filename,"wb");

fprintf(pict,"P6\n");
fprintf(pict,"%d %d\n",nmax+1,nmax+1);
fprintf(pict,"%d\n",max_col+1);


for (i=0;i<=nmax;i++) 
   {
   for (j=0;j<=nmax;j++)
   {
   if (A[i][j]<0.0) A[i][j]=0.0;
   if (B[i][j]<0.0) B[i][j]=0.0;

   l=IMIN(255,(int) (A[i][j]*max_col));
   fwrite(&r[l],sizeof(char),1,pict);
   fwrite(&g[l],sizeof(char),1,pict);
   fwrite(&b[l],sizeof(char),1,pict);
   }
}
fclose(pict);   
printf("%d\n",mypid);
fflush(stdout);

kill (mypid,SIGSTOP);
}
return(0);
}
