/* TigerGraphics Math and Fractal Tool 1.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg */
#include <stdio.h>
#include <math.h>
#include "constructs.h"
#define byte unsigned char

typedef struct { double re; double im; } complex;

int main(int argc, char *argv[]);

int main(int argc, char *argv[])
{
FILE *pict,*colt;

int xsize,ysize,old_xsize,old_ysize,i,j,k,kmax,col,**bild;
double deltx,delty,xmax,xmin,ymax,ymin,d,dmin,xd,yd;
double imgs;

byte r[255],g[255],b[255];
int temp,max_col;
int bxmin,bxmax,bymin,bymax,bxd,byd,iter;
char test;

char filename[256];
char colors[256];

complex z,zn;
complex nullst[3];

complex newton(complex,int);
double dist(complex,complex);
complex sca_mult(double,complex);
complex add(complex,complex);
complex sub(complex,complex);
complex mult(complex,complex);
complex div(complex,complex);

  sscanf(argv[1],"%lf",&xmin);
  sscanf(argv[2],"%lf",&xmax);
  sscanf(argv[3],"%lf",&ymin);
  sscanf(argv[4],"%lf",&ymax);
  sscanf(argv[5],"%d",&bxmin);
  sscanf(argv[6],"%d",&bxmax);
  sscanf(argv[7],"%d",&bymin);
  sscanf(argv[8],"%d",&bymax);
  sscanf(argv[9],"%d",&old_xsize);
  sscanf(argv[10],"%d",&old_ysize);
  sscanf(argv[11],"%d",&iter);
  sscanf(argv[12],"%lf",&imgs);
  sprintf(colors,"%s",argv[13]);
  sprintf(filename,"%s",argv[14]);


nullst[0].re=1.0;
nullst[0].im=0.0;

nullst[1].re=-0.5;
nullst[1].im=0.5*sqrt(3.);

nullst[2].re=-0.5;
nullst[2].im=-0.5*sqrt(3.);

xd=xmax-xmin;
yd=ymax-ymin;

bxd=(bxmax-bxmin);
byd=(bymax-bymin);

if (bxd>byd) {
   xsize=(int) imgs;
   ysize=(int) (imgs*byd)/bxd;
} else {
   ysize=(int) imgs;
   xsize=(int) (imgs*bxd)/byd;
}
xmax=xmin+xd*bxmax/old_xsize;
xmin=xmin+xd*bxmin/old_xsize;
ymax=ymin+yd*(old_ysize-bymin)/old_ysize;
ymin=ymin+yd*(old_ysize-bymax)/old_ysize;

bild=imatrix(0,xsize,0,ysize);

deltx=(xmax-xmin)/xsize;
delty=(ymax-ymin)/ysize;

kmax=-1;

for (i=0;i<xsize;i++)
  {
  z.re=xmin+(double)i*deltx;

  for (j=0;j<ysize;j++)
    {
    z.im=ymin+(double)j*delty;

    zn=newton(z,iter);
    dmin=1000000.;
    col=4;
    for (k=0;k<3;k++)
      {
      d=dist(zn,nullst[k]);
      if (d<dmin)
       {
       dmin=d;
       col=k+1;
       if (col>kmax) kmax=col;
       }
      }

    bild[i][ysize-j-1]=col;
    }
  }

colt=fopen(colors,"r");

k=0;
while ((test=fgetc(colt))!=EOF && k<255)
 {
 ungetc(test,colt);
 fscanf(colt,"%d",&temp);
 r[k]=(unsigned char) temp;
 fscanf(colt,"%d",&temp);
 g[k]=(unsigned char) temp;
 fscanf(colt,"%d",&temp);
 b[k]=(unsigned char) temp;
 k++;
 }
max_col=k-1;
d=(float) max_col/ (float) kmax;

pict=fopen(filename,"wb");
fprintf(pict,"P6\n");
fprintf(pict,"%d %d\n",xsize,ysize);
fprintf(pict,"%d\n",255);

for (j=0;j<ysize;j++)
  {
  for (i=0;i<xsize;i++)
    {
    k=bild[i][j]*d-1;
    fwrite(&r[k],sizeof(byte),1,pict);
    fwrite(&g[k],sizeof(byte),1,pict);
    fwrite(&b[k],sizeof(byte),1,pict);
    }
  }

fclose(pict);


 printf("%12.9g %12.9g %12.9g %12.9g %d %d",
         xmin,xmax,ymin,ymax,xsize,ysize);
 return(0);
}


complex newton(complex z,int max_it)
{
complex sca_mult(double,complex);
complex add(complex,complex);
complex sub(complex,complex);
complex mult(complex,complex);
complex div(complex,complex);
double dist(complex,complex);

int i;
complex z0,z1,z2,z3,eins,null;
eins.re=1.0;
eins.im=0.0;
null.re=0.;
null.im=0.;
z0=z;

for (i=0;i<max_it;i++)
  {
  z2=mult(z0,z0);
  if (dist(z2,null)>1.e-12)
   {
   z1=sub(mult(z2,z0),eins);
   z1=div(z1,sca_mult(3.,z2));
   z3=sub(z0,z1);
   if (dist(z0,z3)<1.e-12) return(z3); else z0=z3;
  }
  else
   {
   return(null);
   }
  }
return(z0);
}
