# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg
proc automatControl {} {
global can ovc
global newworld generation
global plotFontN plotFontS plotFontT
global boldFontN boldFontS boldFontT
global model models name DOS
global show color rule
set show 1

#Setting of the colorbar
#-----------------------
canvas .ov.right.col -height 30 
pack .ov.right.col -fill x
  
set models {Life Wolfram Disease PerBak04 PerBug04 PerBug14 CircularRoom6 CircularRoomN Beetle Diff Adv1DOK Adv1D Adv2D Leopard2 Leopard6}
#if {$DOS!=1} {lappend models Fast-Leopard}

set name(Wolfram) "Wolfram Universe"
set name(Life) "Conway's Life"
set name(Disease) "Disease Spread"
set name(PerBak04) "Per Bak's sandpile (4 Neighbours)"
set name(CircularRoom6) "Circular Room (6 states)"
set name(CircularRoomN) "Circular Room (N states)"
set name(PerBug04) "Buggy Per Bak"
set name(PerBug14) "Buggy Per Bak, fill to 1"
set name(Beetle) "Beetle spread in a forest"
set name(Diff) "Diffusion"
set name(Adv1DOK) "1D Advektion (one cell per time step)"
set name(Adv1D) "1D Advektion (0.1 cell per time step)"
set name(Adv2D) "2D Advektion (0.1 cell per time step)"
set name(Leopard2) "Meinhard-Gierer model (skin of a leopard Db4)"
set name(Leopard6) "Meinhard-Gierer model (skin of a leopard Db8)"
set name(Fast-Leopard) "Meinhard-Gierer model (skin of a leopard) (fast)"

set model Life

#toplevel .ovc
#wm title .ovc { Control panel }
#wm geometry .ovc "+630+250"

frame .ov.right.control
pack .ov.right.control

set ovc .ov.right.control

#Bindings zum Fuellen der Zellen
################################

bind .ov.plot <2> "itemMark .ov.plot %x %y; cellclick %x %y 0"
bind .ov.plot <3> "itemMark .ov.plot %x %y; cellclick %x %y 0"

bind .ov.plot <1> "itemMark .ov.plot %x %y; cellclick %x %y 1"
bind .ov.plot <Shift-1> "itemMark .ov.plot %x %y; cellclick %x %y 2"
bind .ov.plot <Control-1> "itemMark .ov.plot %x %y; cellclick %x %y 3"
bind .ov.plot <Shift-3> "itemMark .ov.plot %x %y; cellclick %x %y 4"
bind .ov.plot <Control-3> "itemMark .ov.plot %x %y; cellclick %x %y 5"
bind .ov.plot <Shift-2> "itemMark .ov.plot %x %y; cellclick %x %y 4"
bind .ov.plot <Control-2> "itemMark .ov.plot %x %y; cellclick %x %y 5"
bind all <Escape> {exit}



# Modellmenu
############
frame $ovc.states
pack $ovc.states -pady 5

menubutton $ovc.states.model -text "Model" -menu $ovc.states.model.menu -font $boldFontN -relief raised
pack  $ovc.states.model -side left -pady 5


set mm [menu $ovc.states.model.menu  -tearoff 0]

foreach item $models {
  $mm add radio -label $name($item) -value $item -variable model -command {setname $ovc.states.model $name($model);clear;automat_init;automat_info}
}

# Zellen-Radiobutton
####################
frame $ovc.radio
pack $ovc.radio -pady 5

label $ovc.radio.titel -text "Cells" -font $boldFontN
pack $ovc.radio.titel -side left -pady 5
if {$DOS==1} {
	set loc {3 10 15 20 25 30} 
} else {
	set loc {3 10 15 20 30 40 50 75 100}
}

foreach item $loc {
   radiobutton $ovc.radio.$item -variable nmax \
              -text $item -font $boldFontN\
              -value [expr $item -1] \
              -command clear
   pack $ovc.radio.$item -side left -pady 5
}



# Grenzen-Radiobutton
####################
frame $ovc.bound
pack $ovc.bound -pady 5

label $ovc.bound.text -text "View of the world" -font $boldFontN
pack $ovc.bound.text -side left -pady 5


radiobutton $ovc.bound.newworld -variable newworld \
              -text "Torus" -font $boldFontN\
              -value 1

pack $ovc.bound.newworld -side left -pady 5

radiobutton $ovc.bound.oldworld -variable newworld \
              -text "Plain" -font $boldFontN\
              -value 0 \

pack $ovc.bound.oldworld -side left -pady 5


frame $ovc.right
pack $ovc.right -side bottom -fill x

frame $ovc.right.but1
pack $ovc.right.but1 -pady 5 -fill x

frame $ovc.right.but2
pack $ovc.right.but2 -pady 5 -fill x

frame $ovc.right.but2a
pack $ovc.right.but2a -pady 5 -fill x

checkbutton $ovc.right.but1.show -text {Show} -variable show -font $boldFontN
pack $ovc.right.but1.show -fill x -side left -padx 0

button $ovc.right.but1.run -text {Run}  -font $boldFontN -width 10\
       -command {set generation 0; runautomat}
pack $ovc.right.but1.run -fill x -side left -padx 0

button $ovc.right.but1.step -text {Step}  -font $boldFontN -width 10\
       -command {set generation 1; runautomat}
pack $ovc.right.but1.step -fill x -side left -padx 0

button $ovc.right.but1.int -text {Interrupt}  -font $boldFontN -width 10\
       -command {set stop 1}
pack $ovc.right.but1.int -fill x -side left -padx 0
 
menubutton  $ovc.right.but2.col -text "Color table" -menu $ovc.right.but2.col.menu -font $boldFontN -relief raised
pack  $ovc.right.but2.col -pady 10 -fill x -side left
set m [menu  $ovc.right.but2.col.menu -tearoff 0]
set labels {default black&white blue&white green&red green&white "red temperature" prism}
foreach lab $labels {
     $m add radio -label $lab -variable coltab -command "makecolor;automat_init" -font $boldFontN
}

button $ovc.right.but2.clear -text {Clear}  -font $boldFontN -width 10\
       -command {clear}
pack $ovc.right.but2.clear -fill x -side left -padx 0  

button $ovc.right.but2.seed -text {Randomfill}  -font $boldFontN -width 10\
       -command {rndfill}
pack $ovc.right.but2.seed -fill x -side left  -padx 0
  

label $ovc.right.but2a.titel -text "Fill" -font $boldFontN

pack $ovc.right.but2a.titel -side left -pady 10

foreach item {1 2 3 4 5 6 7} {
   radiobutton $ovc.right.but2a.$item -variable num \
              -text $item -font $boldFontN\
              -value $item
   pack $ovc.right.but2a.$item -side left -pady 10
}
 $ovc.right.but2a.1 invoke
#spinbox $ovc.right.but2a.spinbox1 -from 1 -to 8 -textvariable num -font $boldFontN
#pack $ovc.right.but2a.spinbox1 -side left -pady 10

button $ovc.right.but2a.fill1 -text {Fill}  -font $boldFontN \
       -command {fill $num}
pack $ovc.right.but2a.fill1 -fill x -side left  -padx 10

button $ovc.right.but2a.print -text {PS Print}  -font $boldFontN \
       -command {printout}
pack $ovc.right.but2a.print -fill x -side left 

# Regelbutton fuer Wolfram
#####################
set rule 126
frame $ovc.rule
pack $ovc.rule -pady 5
label $ovc.rule.e -text "Rule: " -font $boldFontN
pack $ovc.rule.e -side left
entry $ovc.rule.b -width 10 -relief sunken -textvariable rule -font $boldFontN
pack $ovc.rule.b -side left


setname $ovc.states.model $name($model)
start
}

