# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg
proc tools {} {
global install_dir
global can ovc blue lbheight
global toolflag
global boldFontN leopid

toplevel .ov

set ovc .ovc

set canbg white
switch $toolflag {
  automat {set title "Cellular Automata";set canbg $blue}
  fractals {set title "Fractal"}
  bifu {set title "Bifurcation"}
  ifs {set title "IFS"}
  mandel   {set title "Mandelbrot"}
  slope {set title "Slope Field"}
  plot {set title "Function Plot"}

}

set pad 15

wm title .ov "Tiger Graphics $title Tool"

if {$toolflag=="slope" || $toolflag=="automat" || $toolflag=="plot"} {
   wm geometry .ov "[expr $can+2*$pad+550]x[expr $can+2*$pad]+0+0"
} else {
   wm geometry .ov "[expr $can+2*$pad+500]x[expr $can+2*$pad]+0+0"
}

#wm geometry .ov "[expr $can+2*$pad+500]x[expr $can+2*$pad]+0+0"
#wm geometry .ov "[expr $can+2*$pad+550]x[expr $can+2*$pad]+0+0"

# Initializing of the drawing area
#---------------------------------
canvas .ov.plot -bg $canbg -width $can -height $can
pack .ov.plot -side left -padx $pad -pady $pad

frame .ov.right 
pack .ov.right -side top -fill x


.ov.plot bind all <Shift-Button-1> {set id [.ov.plot find closest %x %y] ; .ov.plot delete $id}
                                    
# Initializing of the info window
#---------------------------------
ScrolledListbox .ov.right.msg -height $lbheight
pack .ov.right.msg -side top -fill x

# Initializing of the buttons
#----------------------------
frame .ov.right.button
pack .ov.right.button -fill x 


if {$toolflag=="slope"} {
button .ov.right.button.load -text {Load}  -font $boldFontN  \
       -command {
                  killwin
                  LoadFunc
                  slopeControl
                  #resetscale
                  calc_slope
                  $ovc.left.er.mlinear config -state normal
                 }
pack .ov.right.button.load -side left
}

if {$toolflag=="bifu"} {
button .ov.right.button.load -text {Load}  -font $boldFontN  \
       -command {killwin;LoadFunc; bifuControl}
pack .ov.right.button.load -side left
}

if {$toolflag=="slope" || $toolflag=="bifu"} {
button .ov.right.button.save -text {Save}  -font $boldFontN  \
       -command {SaveFunc}
pack .ov.right.button.save -side left

button .ov.right.button.edit -text {Edit }  -font $boldFontN  \
       -command {EditFunc tgf}
pack .ov.right.button.edit -side left
}


if {$toolflag=="plot"} {

button .ov.right.button.load -text {Load}  -font $boldFontN  \
       -command {killwin;LoadPlotFunc}
pack .ov.right.button.load -side left

button .ov.right.button.save -text {Save}  -font $boldFontN  \
       -command {SavePlotFunc}
pack .ov.right.button.save -side left

button .ov.right.button.edit -text {Edit }  -font $boldFontN  \
       -command {if {$plotmode==1} {set ext tgp} else {set ext tgt};EditFunc $ext}
pack .ov.right.button.edit -side left
}

if {$toolflag=="automat"} {
# Initializing of the color window
#---------------------------------

  button .ov.right.button.load -text {Load} -font $boldFontN\
       -command {LoadAuto}
  pack .ov.right.button.load -side left

  button .ov.right.button.save -text {Save} -font $boldFontN\
       -command {SaveAuto}
  pack .ov.right.button.save -side left

}

# ALL TOOLS
########


button  .ov.right.button.tatze -bitmap @$install_dir/icons/tinylogo.pic -command {tatzetool}
pack  .ov.right.button.tatze -side right 

button  .ov.right.button.exit -text {  Exit  }  -font $boldFontN   -command {
stopsim
set stop -1
killwin
destroy .ov
unsetvar
enablemenu    
set stop -1
if { [info exist leopid] } {
        set command "exec kill -KILL $leopid"
        catch $command result
}
}
pack  .ov.right.button.exit -side right 

button  .ov.right.button.help -text {Help}  -command {help $toolflag} -font $boldFontN
pack  .ov.right.button.help -side right 


# INITIALIZING FRAME FOR WINDOW BUTTONS
if {$toolflag=="x"} {
  frame .ov.right.windows
  pack .ov.right.windows -pady 20 -padx 20 -fill x

  button .ov.right.windows.ovc -text {Arrange Windows}   -font $boldFontN  -command {raisewindows}
  pack .ov.right.windows.ovc -fill x
}

update idletasks

switch $toolflag {
  automat {automatControl}
  fractals {fracControl}
  bifu {bifuControl}
  ifs {ifsControl}
  mandel   {mandelControl}
  slope {slopeControl}
  plot {plotControl}

}
}
